@@ -37,11 +37,11 @@ class CmsViews(BaseCmsView):
     @cache_region(CACHE_TIME)
     def _get_categories(self, locale, order_by):
         return self.workspace.S(Category).filter(
-            language=locale.lower()).order_by(*order_by)
+            language=locale).order_by(*order_by)
 
     @cache_region(CACHE_TIME)
     def get_category(self, uuid):
-        [category] = self.workspace.S(Category).filter(uuid=uuid.lower())
+        [category] = self.workspace.S(Category).filter(uuid=uuid)
         return category
 
     def get_pages(self, limit=5, order_by=('position', '-modified_at')):
@@ -55,12 +55,12 @@ class CmsViews(BaseCmsView):
             defaults to ('position', '-modified_at')
         """
         return self.workspace.S(Page).filter(
-            language=self.locale.lower()).order_by(*order_by)[:limit]
+            language=self.locale).order_by(*order_by)[:limit]
 
     @cache_region(CACHE_TIME)
     def _get_featured_pages(self, locale, limit, order_by):
         return self.workspace.S(Page).filter(
-            language=locale.lower(), featured=True).order_by(*order_by)[:limit]
+            language=locale, featured=True).order_by(*order_by)[:limit]
 
     def get_featured_pages(
             self, limit=5, order_by=('position', '-modified_at')):
@@ -81,7 +81,7 @@ class CmsViews(BaseCmsView):
     def get_pages_for_category(
             self, category_id, locale, order_by=('position',)):
         return self.workspace.S(Page).filter(
-            primary_category=category_id, language=locale.lower()).order_by(
+            primary_category=category_id, language=locale).order_by(
                 *order_by)
 
     def get_featured_category_pages(
@@ -92,7 +92,7 @@ class CmsViews(BaseCmsView):
     @cache_region(CACHE_TIME)
     def _get_featured_category_pages(self, category_id, locale, order_by):
         return self.workspace.S(Page).filter(
-            primary_category=category_id, language=locale.lower(),
+            primary_category=category_id, language=locale,
             featured_in_category=True).order_by(*order_by)
 
     @cache_region(CACHE_TIME)
@@ -101,7 +101,7 @@ class CmsViews(BaseCmsView):
             query = self.workspace.S(Page).filter(
                 F(uuid=uuid) | F(slug=slug))
             if locale is not None:
-                query = query.filter(language=locale.lower())
+                query = query.filter(language=locale)
             [page] = query[:1]
             return page
         except ValueError:
@@ -114,7 +114,7 @@ class CmsViews(BaseCmsView):
     @cache_region(CACHE_TIME)
     def _get_top_nav(self, locale, order_by):
         return self.workspace.S(Category).filter(
-            language=locale.lower(),
+            language=locale,
             featured_in_navbar=True).order_by(*order_by)
 
     @view_config(route_name='home', renderer='cms:templates/home.pt')
